Learn R Programming

BasketTrial (version 0.1.0)

JSD: JSD (Fujikawa et al., 2020) Method for Bayesian Basket Trial

Description

JSD (Fujikawa et al., 2020) Method for Bayesian Basket Trial

Usage

JSD(nDat, yDat, be.a0 = NULL, be.b0 = NULL, epsilon = 2, tau = 0.3)

Value

It returns a list including the posterior beta parameters and similarity matrix.

Arguments

nDat

a vector of length B for the sample size in each basket.

yDat

a vector of length B for the number of responses in each basket.

be.a0

a vector of length B for beta prior parameter a0 in each basket.

be.b0

a vector of length B for beta prior parameter b0 in each basket.

epsilon

the global control parameter in the JSD model.

tau

the threshold parameter in the JSD model.

References

Fujikawa, K., Teramukai, S., Yokota, I., & Daimon, T. (2020). A Bayesian basket trial design that borrows information across strata based on the similarity between the posterior distributions of the response probability. Biometrical Journal, 62(2), 330-338.

Examples

Run this code
JSD(nDat = c(25, 25, 25, 25, 25), yDat = c(2,9,11,13,20))

Run the code above in your browser using DataLab