powered by
Local Power Prior for Bayesian Basket Trial
localPP( nDat, yDat, be.a0 = NULL, be.b0 = NULL, a = 1, delta = 0.4, method = "PEB", symmetry = FALSE )
It returns a list including the posterior beta parameters and similarity matrix.
a vector of length B for the sample size in each basket.
a vector of length B for the number of responses in each basket.
a vector of length B for beta prior parameter a0 in each basket.
a vector of length B for beta prior parameter b0 in each basket.
the global control parameter in the local PP 3-component framework.
the threshold parameter in the local PP 3-component framework.
either PEB for the pairwise empirical Bayes or GEB for the global empirical Bayes.
PEB
GEB
logical variable to indicate whether the similarity matrix will be set to be symmetric; default is FALSE.
FALSE
Zhou, H., Shen, R., Wu, S., & He, P. (2023). A Bayesian Basket Trial Design Using Local Power Prior. arXiv preprint arXiv:2312.15352.
localPP(nDat = c(25, 25, 25, 25, 25), yDat = c(2,9,11,13,20), be.a0 = rep(0.5, 5), be.b0 = rep(0.5, 5), a = 4, delta = 1, method = "PEB")
Run the code above in your browser using DataLab