It returns a list including the posterior beta parameters and similarity matrix.
Arguments
nDat
a vector of length B for the sample size in each basket.
yDat
a vector of length B for the number of responses in each basket.
be.a0
a vector of length B for beta prior parameter a0 in each basket.
be.b0
a vector of length B for beta prior parameter b0 in each basket.
epsilon
the global control parameter in the JSD model.
tau
the threshold parameter in the JSD model.
References
Fujikawa, K., Teramukai, S., Yokota, I., & Daimon, T. (2020).
A Bayesian basket trial design that borrows information across strata based on
the similarity between the posterior distributions of the response probability.
Biometrical Journal, 62(2), 330-338.